#------------------------------------------------------------------------
# This file is distributed under the Common Public License.
# It is part of the TestTools project in COIN-OR (www.coin-or.org)
#------------------------------------------------------------------------

#----------------------------------------------------------------------
# This file is a template for a user-given parameter file.
# It contains variables that the person running this script need to set or modify.
#----------------------------------------------------------------------

#----------------------------------------------------------------------
# NIGHTLY_BUILD_ROOT_DIR: 
#   directory where code will be checked out and builds
#   done. If the directory does not exist, it will be created.
#
#   This should be the full path, not a path relative to the
#   nightlyBuild script.
#
#   examples for both unix and windows:
#      NIGHTLY_BUILD_ROOT_DIR = '/home/userid/nbBuildDir'
#      NIGHTLY_BUILD_ROOT_DIR = r'c:\nbBuildDir'
#----------------------------------------------------------------------
NIGHTLY_BUILD_ROOT_DIR = '/xxx'

#----------------------------------------------------------------------
# List of Projects to be processed by script
#----------------------------------------------------------------------
PROJECTS = ['CoinUtils','Clp','Osi','DyLP','SYMPHONY','Vol','Cgl','Cbc','Smi','FlopC++','Ipopt','Bonmin','OS','CppAD','CoinAll']

#----------------------------------------------------------------------
# Addition of GAMSlinks project to list of projects
# Note that testing and sometimes the compilation of the GAMSlinks
# project requires a GAMS system installed in your system.
# A demo system can be obtained from www.gams.com and is sufficent
# to run the tests.
# Further, GAMSlinks needs to know the location of your GAMS system.
# The easiest way is to have this path in your PATH environment variable.
# Note also, that the tests for the GAMSlinks project automatically
# attempt to install the solver links in your GAMS system before testing.
# Finally, GAMSlinks builds only on some selected platforms, see website.
# Windows is very likely to fail.
# Adding -DDISALLOW_PRINTING to the CXXFLAGS truns off printing to
# stdout in Cbc. It might be required to pass the tests. 
#----------------------------------------------------------------------

#PROJECTS.append('GAMSlinks')

#----------------------------------------------------------------------
#  Define how a COIN-OR project is to be built and tested.
#  A project can be built multiple times in different ways.
#
#  SvnVersion: Specifies where in subversion the source should be obtained.
#   Examples: 'trunk', 'latestStable', 'releases/1.2.0'
#
#  OptLevel: 'Default' or 'Debug'. Specifies if "./configure" needs
#   additional parameters to build with debug.  The default is supposed
#   to be an optimized build.
#   This is ignored on windows when building with MS compiler solution file
#   because both Release and Debug are built.
#
#  ThirdParty: 'Yes' or 'No'.  Some projects provide scripts for downloading
#   third party code. If 'Yes' then these scripts will be run. If 'No'
#   then the options for skipping the use of third party codes are
#   used when running "./configure".
#   Presently this ignored on windows when building with MS compiler 
#   solution file because ThirdParty code is never used.
#
#  'AdditionConfigOptions': This provides the ability to specify an
#    additional './configure' option to be applied to this specific build.
#    CONFIGURE_FLAGS can be set if one wants to specify addtional configure
#    options to all builds.
#    Example: '--enable-cbc-parallel'
#    This is ignored on windows when building with MS compiler solution file
#    because configure is not run.
#
#  'Run' : 'always', 'noSuccessOrAfterChange', 'afterChange'
#    This specifies when a specific configuration will be run.
#    nightlyBuild can determine if the source code has been updated
#    since the last run. nightlyBuild also records when a run 
#    successful run has occured.  This can be used to decide if a new
#    run should be done.
#    'always': the configuration is always run.  This is useful for
#              debugging.
#    'noSuccessOrAfterChange': This is the default behavior.  If
#              the prior run did not successfully complete or
#              the source code has changed then the run is done.
#    'afterChange': Only run if the source code has changed since
#              the last run.  This is useful if there is a known
#              problem that is waiting for a fix. There is no
#              point in repeating a known failure unless a possible
#              fix has been committed to svn.
#
#  'Reference': This specifies that the build is to be done in the way
#    of the referenced name.
#    Example: 'CoinUtils'
#    The example indicates that the build configurations specified
#    for CoinUtils are to be used for building.
#
#  'SkipProjects': Give a list of external projects that are skipped
#    by the corresponding build. This list of projects is added to the
#    COIN_SKIP_PROJECTS variable of the configure call.
#    Example: ['Ipopt', 'ThirdParty/HSL']
#    Note, that you need to use brackets "[ ]" here, not parentheses "( )".
#
#----------------------------------------------------------------------
BUILDS = {
   #'DefaultProject'   : 
   #  [ 
   #    { 'SvnVersion': 'trunk',        'OptLevel': 'Default', 'ThirdParty':'Yes' }, 
   #    { 'SvnVersion': 'latestStable', 'OptLevel': 'Debug',   'ThirdParty':'No'  } 
   #  ],
   'CoinUtils' : 
     [
       { 'SvnVersion': 'trunk',         'OptLevel': 'Default', 'ThirdParty': 'No' } 
     #,{ 'SvnVersion': 'trunk',         'OptLevel': 'Debug',   'ThirdParty': 'No' } 
     #,{ 'SvnVersion': 'latestStable',  'OptLevel': 'Default', 'ThirdParty': 'No' } 
     #,{ 'SvnVersion': 'latestStable',  'OptLevel': 'Debug',   'ThirdParty': 'No' } 
     #,{ 'SvnVersion': 'latestRelease', 'OptLevel': 'Default', 'ThirdParty': 'No' }  
     #,{ 'SvnVersion': 'latestRelease', 'OptLevel': 'Debug',   'ThirdParty': 'No' } 
     ],
   'Osi' : 
     [ 
       { 'Reference' : 'CoinUtils' }
     ],
   'Clp' : 
     [ 
       { 'Reference' : 'CoinUtils' }
     ],
   'DyLP' : 
     [ 
       { 'Reference' : 'CoinUtils' }
     ],
   'SYMPHONY' : 
     [ 
       { 'Reference' : 'CoinUtils' }
     ],
   'Vol' : 
     [ 
       { 'Reference' : 'CoinUtils' }
     ],
   'Cgl' : 
     [ 
       { 'Reference' : 'CoinUtils' }
     ],
   'Cbc' : 
     [ 
       { 'Reference' : 'CoinUtils' } 

       # And build a parallel version with Third Party
     #,{ 
     #   'SvnVersion': 'latestStable', 
     #   'OptLevel': 'Default', 
     #   'ThirdParty': 'Yes', 
     #   'AdditionalConfigOptions': '--enable-cbc-parallel' 
     # }
     ],
   'Smi' : 
     [ 
       { 'Reference' : 'CoinUtils' } 
     ],
   'FlopC++' : 
     [ 
       { 'Reference' : 'CoinUtils' }
     ],
   'Ipopt' : 
     [ 
       { 'SvnVersion': 'trunk',        'OptLevel': 'Default', 'ThirdParty':'Yes' }
     #,{ 'SvnVersion': 'trunk',        'OptLevel': 'Debug',   'ThirdParty':'Yes' }
     #,{ 'SvnVersion': 'latestStable', 'OptLevel': 'Default', 'ThirdParty':'Yes' }
     #,{ 'SvnVersion': 'latestRelease','OptLevel': 'Default', 'ThirdParty':'Yes' }
     ],
   'CoinAll' :
     [
       { 'SvnVersion': 'trunk', 'OptLevel': 'Default', 'ThirdParty':'Yes' },
       { 'SvnVersion': 'trunk', 'OptLevel': 'Debug',   'ThirdParty':'Yes' }
     ],
   'LaGO' :
     [
       { 'Reference' : 'Ipopt' },
     ],
   'Bonmin' : 
     [ 
       { 'SvnVersion': 'trunk',        'OptLevel': 'Default', 'ThirdParty':'Yes' }
      #,{ 'SvnVersion': 'branches/0.9', 'OptLevel': 'Default', 'ThirdParty':'Yes' }
     ],
   'OS' :
     [ 
       { 'Reference' : 'Ipopt' } 
     #,{ 'SvnVersion': 'trunk',        'OptLevel': 'Default', 'ThirdParty': 'No', 'SkipProjects': ['Ipopt'] } 
     #,{ 'SvnVersion': 'trunk',        'OptLevel': 'Debug',   'ThirdParty': 'No', 'SkipProjects': ['Ipopt'] } 
     #,{ 'SvnVersion': 'latestStable', 'OptLevel': 'Default', 'ThirdParty': 'No', 'SkipProjects': ['Ipopt'] } 
     #,{ 'SvnVersion': 'latestRelease','OptLevel': 'Default', 'ThirdParty': 'No', 'SkipProjects': ['Ipopt'] } 
     ],
   'CppAD' : 
     [ 
       { 'SvnVersion': 'trunk',        'OptLevel': 'Default', 'ThirdParty': 'No', 'AdditionalConfigOptions':'--with-Example --with-TestMore' } 
     #,{ 'SvnVersion': 'trunk',        'OptLevel': 'Debug',   'ThirdParty': 'No', 'AdditionalConfigOptions':'--with-Example --with-TestMore' } 
     #,{ 'SvnVersion': 'latestStable', 'OptLevel': 'Default', 'ThirdParty': 'No', 'AdditionalConfigOptions':'--with-Example --with-TestMore' } 
     #,{ 'SvnVersion': 'latestRelease','OptLevel': 'Default', 'ThirdParty': 'No', 'AdditionalConfigOptions':'--with-Example --with-TestMore' } 
     ],
   'GAMSlinks' : 
     [ 
       { 'Reference' : 'Ipopt' }
     ]
  }

#----------------------------------------------------------------------
#On some systems the user might want to set extra options for the
#configure script like compilers...
#example: CONFIGURE_FLAGS = 'CC="gcc" CXX="g++" F77="gfortran" ADD_CXXFLAGS="-m64" ADD_CFLAGS="-m64" ADD_FFLAGS="-m64"'
#----------------------------------------------------------------------

CONFIGURE_FLAGS = ''

#---------------------------------------------------------------------
#On some systems, e.g. Windows/msys32, you might want to specify the
#name of the make program. 
#example: MAKECMD='gmake'
#---------------------------------------------------------------------

MAKECMD = 'make'

#----------------------------------------------------------------------
#Normally, nightlyBuild does not remove old builds before rebuilding
#a configuration, instead configure might be called and make needs to
#recompile files that changed.
#Setting this flag to 1 makes nightlyBuild remove a build directory
#completely before starting a configure/make/tests run.
#Note, that this can slow down the an anew build significantly. Thus,
#you might consider to use a tool like ccache (http://ccache.samba.org).
#After installing ccache and making it available in the $PATH, putting
#CONFIGURE_FLAGS = 'CC="ccache gcc" CXX="ccache g++" F77="ccache g77"'
#should make nightly build use ccache.
#----------------------------------------------------------------------

CLEAR_PREVIOUS_BUILD = 0




#----------------------------------------------------------------------
# LOGPRINT:
#   switch for logoutput to stdout. If set to 1 (default) log will go to
#   stdout, if set to 0, then not.
# LOGFILE: 
#   If not empty, then log messages will go to this file.
#   If LOGPRINT is 1, then log messages will go to stdout as well.
#   The LOGFILE will be used relative to the NIGHTLY_BUILD_ROOT_DIR, i.e.,
#   log will be written into NIGHTLY_BUILD_ROOT_DIR+'/'+LOGFILE
#----------------------------------------------------------------------
LOGPRINT = 1
LOGFILE = ''

#----------------------------------------------------------------------
# Values for sending mail:
#  EMAIL_STOREFILE: If set, then e-mails are not send but stored in a file.
#                   The filename is relative to NIGHTLY_BUILD_ROOT_DIR.
#                   If set, then no values for the SMTP_ fields need to be given.
#  SMTP_SERVER_NAME: name of smtp server. For gmail server 
#                 this is smtp.gmail.com
#  SMTP_SERVER_PORT: port number of the smtp server. This is typically 25,
#                 but for gmail server it is 587.
#  SMTP_SSL_SERVER: 0 or 1. If 1 then SMTP uses SSL (sometimes called startltls).
#                 For gmail this is 1.
#  SMTP_USER_NAME: name of authorized user on server. If using gmail server
#                 this is gmail_userid@gmail.com which is coded as
#                 'gmail_userid _AT_ gmail _DOT_ com.  
#  SMTP_PASSWORD_FILENAME: name of file containing smtp user's password
#  SENDER_EMAIL_ADDR: email sent by this script will be from this address
#  MY_EMAIL_ADDR: All problems detected by the script will be sent to
#                 this email address. The intention is for this to be
#                 the email address of the person running this script
#  SEND_MAIL_TO_PROJECT_MANAGER: 0 or 1. If 1 then any problems
#                 detected are sent to MY_EMAIL_ADDRESS and the
#                 project manager.
#----------------------------------------------------------------------
EMAIL_STOREFILE = ''

SMTP_SERVER_NAME = 'xxx.smtp.server.name'
SMTP_SERVER_PORT = 25
SMTP_SSL_SERVER = 0
SMTP_USER_NAME = 'xxxx'
SMTP_PASSWORD_FILENAME = '/xxx/yyy/smtpPassWordFile'
SENDER_EMAIL_ADDR='xxx _AT_ yyyy _DOT_ edu'
MY_EMAIL_ADDR = SENDER_EMAIL_ADDR

SEND_MAIL_TO_PROJECT_MANAGER = 0


#----------------------------------------------------------------------
# The nightlyBuild will not build a binary by default
# If you want binaries built set the flag
# BUILD_BINARIES = 1
# It is 0 by default
# Note: Binaries of project containing ThirdParty software will not be built
#----------------------------------------------------------------------

BUILD_BINARIES = 0

#----------------------------------------------------------------------
# You may wish to include compiler or other build information in the binary build name
# By default it is null
#----------------------------------------------------------------------

BUILD_INFORMATION = ''



#----------------------------------------------------------------------
# When this parameter is set 1 we force the use of vcbuild in Windows if
# if msys/cygwin/mingw is present
#----------------------------------------------------------------------

FORCE_VCBUILD = 2


#----------------------------------------------------------------------
# Sometimes an svn update does not work and we need to try a second 
# or third time. The default is just one.  Increase this number if
# desired in your NBuserParameters.py file.
#----------------------------------------------------------------------

SVN_UPDATE_TRIALS = 1


#----------------------------------------------------------------------
# In Linux you may wish to run valgrind to check for memory leaks.
# This feature is off by default
#----------------------------------------------------------------------

VALGRIND_TEST = False

#----------------------------------------------------------------------
# Below is a list of acceptable Third Party code to include
# in the binary distribution
#----------------------------------------------------------------------

ThirdPartyAllowed = ['ASL', 'Blas', 'Lapack', 'Mumps', 'GAMSIO']
